@@ -11,8 +11,6 @@
 #' @param overwrite (logical) Ovewrite a file if one is found with the same name
 #' @param mssgs (logical) print information messages. Default: `TRUE`
 #' @param ... Curl options passed on to [crul::HttpClient]
-#' @param prompt (logical) Prompt before clearing all files in cache? No prompt
-#' used when DOIs assed in. Default: `TRUE`
 #' @return One or more items of class pangaea, each with the doi, parent doi
 #' (if many dois within a parent doi), url, citation, path, and data object.
 #' Data object depends on what kind of file it is. For tabular data, we print
@@ -22,8 +20,9 @@
 #' @author Naupaka Zimmerman, Scott Chamberlain
 #' @references <https://www.pangaea.de>
 #' @details Data files are stored in an operating system appropriate location.
-#' Run `rappdirs::user_cache_dir("pangaear")` to get the storage location
-#' on your machine.
+#' Run `pg_cache$cache_path_get()` to get the storage location
+#' on your machine. See [pg_cache] for more information, including how to
+#' set a different base path for downloaded files.
 #'
 #' Some files/datasets require the user to be logged in. For now we
 #' just pass on these - that is, give back nothing other than metadata.
@@ -33,6 +32,7 @@
 #' res[[1]]$doi
 #' res[[1]]$citation
 #' res[[1]]$data
+#' res[[1]]$metadata
 #'
 #' # another single file
 #' pg_data(doi='10.1594/PANGAEA.807584')
@@ -44,31 +44,22 @@
 #'
 #' # Manipulating the cache
 #' ## list files in the cache
-#' pg_cache_list()
+#' pg_cache$list()
 #'
 #' ## clear all data
-#' # pg_cache_clear()
-#' pg_cache_list()
+#' # pg_cache$delete_all()
+#' pg_cache$list()
 #'
 #' ## clear a single dataset by DOI
 #' pg_data(doi='10.1594/PANGAEA.812093')
-#' pg_cache_list()
-#' pg_cache_clear(doi='10.1594/PANGAEA.812093')
-#' pg_cache_list()
-#'
-#' ## clear more than 1 dataset by DOI
-#' lapply(c('10.1594/PANGAEA.746398','10.1594/PANGAEA.746400'), pg_data)
-#' pg_cache_list()
-#' pg_cache_clear(doi=c('10.1594/PANGAEA.746398','10.1594/PANGAEA.746400'))
-#' pg_cache_list()
+#' pg_cache$list()
+#' path <- grep("PANGAEA.812093", pg_cache$list(), value = TRUE)
+#' pg_cache$delete(path)
+#' pg_cache$list()
 #'
 #' # search for datasets, then pass in DOIs
 #' (searchres <- pg_search(query = 'birds', count = 20))
 #' pg_data(searchres$doi[1])
-#' pg_data(searchres$doi[2])
-#' pg_data(searchres$doi[3])
-#' pg_data(searchres$doi[4])
-#' pg_data(searchres$doi[7])
 #'
 #' # png file
 #' pg_data(doi = "10.1594/PANGAEA.825428")
@@ -86,7 +77,7 @@ pg_data <- function(doi, overwrite = TRUE, mssgs = TRUE, ...) {
   citation <- attr(dois, "citation")
   if (mssgs) message("Downloading ", length(dois), " datasets from ", doi)
   invisible(lapply(dois, function(x) {
-    if ( !is_pangaea(env$path, x) ) {
+    if ( !is_pangaea(pg_cache$cache_path_get(), x) ) {
       pang_GET(url = paste0(base(), x), doi = x, overwrite, ...)
     }
   }))
@@ -107,13 +98,19 @@ print.pangaea <- function(x, ...) {
 }
 
 pang_GET <- function(url, doi, overwrite, ...){
-  dir.create(env$path, showWarnings = FALSE, recursive = TRUE)
+  bpath <- pg_cache$cache_path_get()
+  dir.create(bpath, showWarnings = FALSE, recursive = TRUE)
 
-  cli <- crul::HttpClient$new(url = url, 
+  cli <- crul::HttpClient$new(url = url,
     opts = list(followlocation = TRUE, ...))
   res <- cli$get(query = list(format = "textfile"))
   res$raise_for_status()
 
+  # remove spaces in content type header, if present
+  # so we can keep the below code the same
+  res$response_headers$`content-type` <- 
+    gsub("\\s", "", res$response_headers$`content-type`)
+
   # if login required, stop with just metadata
   if (grepl("text/html", res$response_headers$`content-type`)) {
     if (
@@ -137,12 +134,12 @@ pang_GET <- function(url, doi, overwrite, ...){
   )
   switch(
     res$response_headers$`content-type`,
-    `image/png` = png::writePNG(png::readPNG(res$content), file.path(env$path, fname)),
+    `image/png` = png::writePNG(png::readPNG(res$content), file.path(bpath, fname)),
     `text/tab-separated-values;charset=UTF-8` = {
-      writeLines(res$parse("UTF-8"), file.path(env$path, fname))
+      writeLines(res$parse("UTF-8"), file.path(bpath, fname))
     },
     `application/zip` = {
-      path <- file(file.path(env$path, fname), "wb")
+      path <- file(file.path(bpath, fname), "wb")
       writeBin(res$content, path)
       close(path)
     }
@@ -151,7 +148,7 @@ pang_GET <- function(url, doi, overwrite, ...){
 
 process_pg <- function(x, doi, citation) {
   lapply(x, function(m) {
-    file <- list.files(env$path, pattern = gsub("/|\\.", "_", m),
+    file <- list.files(pg_cache$cache_path_get(), pattern = gsub("/|\\.", "_", m),
                        full.names = TRUE)
     if (length(file) == 0) {
       list(
@@ -160,6 +157,7 @@ process_pg <- function(x, doi, citation) {
         citation = citation,
         url = paste0("https://doi.org/", m),
         path = NA,
+        metadata = NA,
         data = NA
       )
     } else {
@@ -169,6 +167,7 @@ process_pg <- function(x, doi, citation) {
         citation = citation,
         url = paste0("https://doi.org/", m),
         path = file,
+        metadata = read_meta(file),
         data = {
           ext <- strsplit(basename(file), "\\.")[[1]][2]
           switch(
@@ -176,7 +175,7 @@ process_pg <- function(x, doi, citation) {
             zip = utils::unzip(file, list = TRUE),
             txt = {
               dat <- read_csv(file)
-              tibble::as_data_frame(dat, validate = FALSE)
+              tibble::as_tibble(dat, validate = FALSE)
             },
             png = "png; read with png::readPNG()"
           )
@@ -196,13 +195,13 @@ is_pangaea <- function(x, doi){
 
 rdoi <- function(x, ext = ".txt") paste0(gsub("/|\\.", "_", x), ext)
 
-check_many <- function(x){
+check_many <- function(x) {
   res <- crul::HttpClient$new(url = fix_doi(x))$get()
   txt <- xml2::read_html(res$parse("UTF-8"))
   dc_format <- xml2::xml_attr(
     xml2::xml_find_first(txt, "//meta[@name=\"DC.format\"]"), "content")
-  cit <- xml2::xml_text(
-    xml2::xml_find_first(txt, "//h1[@class=\"MetaHeaderItem citation\"]"))
+  cit <- xml2::xml_attr(
+    xml2::xml_find_first(txt, "//meta[@name=\"description\"]"), "content")
   attr(x, "citation") <- cit
 
   if (grepl("zip", dc_format) && !grepl("datasets", dc_format)) {
@@ -213,7 +212,7 @@ check_many <- function(x){
     unique(xml2::xml_length(
       xml2::xml_find_all(
         txt,
-        ".//div[@class=\"MetaHeaderItem\"]//a[@rel=\"follow\"]"
+        ".//a[@rel=\"follow\"]"
       )
     )) == 0
   ) {
@@ -224,7 +223,7 @@ check_many <- function(x){
       "https://doi.pangaea.de/", "",
       xml2::xml_attr(
         xml2::xml_find_all(txt,
-            ".//div[@class=\"MetaHeaderItem\"]//a[@rel=\"follow\"]"
+          ".//a[@rel=\"follow\"]"
         ),
         "href"
       )
